<template>
  <slot v-bind="{ open: () => modal.open(), close: () => modal.close() }" />
  <ModalDialog
    ref="deleteModal"
    size="md"
    without-dismiss
  >
    <ConfirmDeleteModal
      :is-loading="userRoleDeleteFetch.isFetching"
      description="app.admin.user_roles.delete.description"
      title="app.admin.user_roles.delete.title"
      @close="modal.close"
      @confirm="submit"
    />
  </ModalDialog>
</template>

<script lang="ts" setup>
import ModalDialog from "@/js/contexts/shared/ui/components/modal/ModalDialog.vue";
import useModal from "@/js/contexts/shared/composables/useModal";
import ConfirmDeleteModal from "@/js/contexts/shared/ui/modals/ConfirmDeleteModal.vue";
import useFetch from "@/js/contexts/shared/composables/useFetch";
import useNotification from "@/js/contexts/shared/composables/useNotification";

const props = defineProps<{
  id: string;
}>();

const emit = defineEmits<{
  confirm: [];
}>();

defineSlots<{
  default(props: { open: () => void; close: () => void }): void;
}>();

const { t } = useI18n();
const { successNotification, errorNotification } = useNotification();

const deleteModal = ref<InstanceType<typeof ModalDialog>>();
const modal = useModal(deleteModal);
const userRoleDeleteFetch = useFetch(`/api/admin/user-roles/${props.id}`);

const submit = () => {
  userRoleDeleteFetch.delete(null, {
    onSuccess: () => {
      emit("confirm");
      successNotification(t("app.admin.user_roles.delete.success"));
      modal.close();
    },
    onError: (e) => {
      errorNotification(e.response?.data?.message ?? t("app.admin.user_roles.delete.failed"));
    },
  });
};
</script>
